summaryrefslogtreecommitdiff
path: root/update_daemon2.php
diff options
context:
space:
mode:
authorAndrew Dolgov <[email protected]>2009-01-16 12:06:42 +0100
committerAndrew Dolgov <[email protected]>2009-01-16 12:06:42 +0100
commite3b5469373d81134d2752f5bcaa08460961f3676 (patch)
tree1f1406c9cf7e86bfe6e9f373cc63e4c3351c3ced /update_daemon2.php
parent6c8feb8f1264469b30c7f57e2e98165ece5e5c3e (diff)
regenerate feedbrowser cache from the update daemon
Diffstat (limited to 'update_daemon2.php')
-rw-r--r--update_daemon2.php11
1 files changed, 9 insertions, 2 deletions
diff --git a/update_daemon2.php b/update_daemon2.php
index 08f5d74c3..a85bc1f52 100644
--- a/update_daemon2.php
+++ b/update_daemon2.php
@@ -174,8 +174,15 @@
// $last_purge = time();
// }
- // Call to the feed batch update function
- update_daemon_common($link);
+ // Call to the feed batch update function
+ // or regenerate feedbrowser cache
+
+ if (rand(0,100) > 50) {
+ update_daemon_common($link);
+ } else {
+ $count = update_feedbrowser_cache($link);
+ _debug("Finished, $count feeds processed.");
+ }
_debug("Elapsed time: " . (time() - $start_timestamp) . " second(s)");